
$(document).ready(function () {
 $('.toggle-task-template').on('click', function(event) {
    event.preventDefault();

    var taskId = $(this).data('task-id');
    var $task = $('.task[data-id="' + taskId + '"]');

    $task.find('#taskFull' + taskId).slideToggle();

    var $shortSummary = $task.find('.task-template-short-summary');
    if ($shortSummary.is(':visible')) {
      $shortSummary.hide();
      $(this).text(i18nTranslations.collapse);
    } else {
      $shortSummary.show();
      $(this).text(i18nTranslations.view);
    }
  });
});

//Show include task options in new task modal
$(document).on('click', '#new-task-template-modal .show_include_task', function (e) {
  var self = $(this).parent();

  if(self.hasClass("on")) {
    self.removeClass("on");
    $("#task_template_execution").val(false);
    $(".include-task").fadeOut('fast');
  } else {
    self.addClass("on");
    $("#task_template_execution").val(true);
    $(".include-task").fadeIn('fast');
  }
});

$(document).on('click', '#edit-task-template-modal .show_include_task', function (e) {
  var self = $(this).parent();

  if(self.hasClass("on")) {
    self.removeClass("on");
    $("#task_template_execution").val(false);
    $(".include-task").fadeOut('fast');
  } else {
    self.addClass("on");
    $("#task_template_execution").val(true);
    $(".include-task").fadeIn('fast');
  }
});

function humanizeText(str) {
  return str
    .split('_')
    .map(function(word) {
      return word.charAt(0).toUpperCase() + word.slice(1);
    })
    .join(' ');
}

// Adapt actions select for each integration
$(document).on("change", "#task_template_integration_service", function(event) {
  var integrationService = $(this).val();
  if (integrationService) {
    $.ajax({
         url: '/playbook_templates/integration_service_actions/' + integrationService,
         dataType: 'json',
         success: function(data) {

           // Limpiar las opciones actuales del select de acciones
           var $actionSelect = $("#task_template_action");
           $actionSelect.empty();

           // Popular el select con las nuevas opciones
           $.each(data, function(index, value) {
               $actionSelect.append($('<option>', {
                   value: value,
                   text: humanizeText(value)
               }));
           });
         }
     });
   } else {
     var $actionSelect = $("#task_template_action");
     $actionSelect.empty();
   }
 });

// Adapt actions select for each integration in automatic actions
$(document).on("change", "#playbook_template_automatic_action_integration_service", function(event) {
  var integrationService = $(this).val();
  if (integrationService) {
    $.ajax({
         url: '/playbook_templates/integration_service_actions/' + integrationService,
         dataType: 'json',
         success: function(data) {

           var $actionSelect = $("#playbook_template_automatic_action_action");
           $actionSelect.empty();

           $.each(data, function(index, value) {
               $actionSelect.append($('<option>', {
                   value: value,
                   text: humanizeText(value)
               }));
           });
         }
    });
  } else {
    var $actionSelect = $("#playbook_template_automatic_action_action");
    $actionSelect.empty();
  }
});

// Saves the actions as cache
var integrationServicesCache = {};
var selectedInput = null;

function fetchActionsForIntegration(integration, action, index, default_value) {
  index = index !== undefined ? index : null;
  default_value = default_value !== undefined ? default_value : null;
  var cacheKey = integration + "-" + action;

  if (integrationServicesCache[cacheKey]) {
    generateInputsForAction(integrationServicesCache[cacheKey], index, default_value);
  } else {
    $.ajax({
      url: "/playbook_templates/integration_service_action_params/" + encodeURIComponent(integration) + "/" + encodeURIComponent(action),
      method: "GET",
      success: function(response) {
        integrationServicesCache[cacheKey] = response;
        generateInputsForAction(response, index, default_value);
      },
      error: function() {
        console.error("Error loading data for", integration, action);
      }
    });
  }
}

function generateInputsForAction(data, index, default_value) {
  if (index === null) {
    return;
  }

  var stepId = "step-" + (index + 1);
  var stepIntegration = selected_actions[index - 1]["integration"];
  var stepAction = selected_actions[index - 1]["action"];

  var stepHtml = '<div class="wizard-step hidden" id="' + stepId + '">';
  default_value = JSON.parse(default_value);

  stepHtml += '<h4>' + humanizeText(stepIntegration) + ': ' + humanizeText(stepAction) + '</h4>';

  if (Object.keys(data).length) {
    Object.keys(data).forEach(function(param) {
      var paramConfig = data[param];
      stepHtml += '<div class="form-group">';
      stepHtml += '<label' + (paramConfig.required ? ' class="required"' : '') + '>' +
                  (paramConfig.required ? '* ' : '') + humanizeText(param) + '</label>' +
                  '<div style="display:flex; gap:5px;">';

      var inputValue = default_value !== null && default_value[param] !== undefined ? default_value[param] : '';
      var inputAttributes = 'name="automatic_actions[' + stepIntegration + '][' + stepAction + '][' + (index - 1) + '][' + param + ']" class="form-control"' +
                            (paramConfig.required ? ' data-required="true"' : '');

      if (paramConfig.type === "integer") {
        stepHtml += '<input type="number" ' + inputAttributes + ' value="' + inputValue + '">';
      } else if (paramConfig.type === "array") {
        stepHtml += '<textarea ' + inputAttributes + '>' + inputValue + '</textarea>';
      } else {
        stepHtml += '<input type="text" ' + inputAttributes + ' value="' + inputValue + '">';
      }

      stepHtml += '<button type="button" class="btn incident-fields-btn" ' +
                  'data-target="#incident-fields-automatic-action-modal" data-backdrop="static" ' +
                  'data-index="' + (index - 1) + '" data-param="' + param + '">' +
                  '<i class="fa fa-external-link"></i>' +
                  '</button>';

      stepHtml += '</div></div>';
    });
  } else {
    stepHtml += '<p>' + I18n.t('playbook_templates.new_playbook_template_modal.no_params_needed') + '</p>' +
                '<input type="text" name="automatic_actions[' + stepIntegration + '][' + stepAction + '][' + (index - 1) + ']" class="form-control hidden">';
  }

  stepHtml += '</div>';
  dynamicStepsContainer.insertAdjacentHTML('beforeend', stepHtml);
}

// From [{i:i, a:a}, {i:i, a:a2}, {i:i2, a:a3}]
// To   [{i:i, a:[a, a2]}, {i:i2, a:[a3]}]
function reducer_selected_actions(parsed, current_action) {
  var existing = parsed.find(function (item) {
    return item.integration === current_action.integration;
  });

  if (existing) {
    existing.actions.push(current_action.action);
  } else {
    parsed.push({
      integration: current_action.integration,
      actions: [current_action.action]
    });
  }

  return parsed;
}
